from setuptools import setup

setup(name='Gaussandbinomial',
      version='0.3',
      description='Gaussian and Binomial distributions',
      packages=['Gaussandbinomial'],
      author='Pranali Parab',
      author_mail= 'pranaliparab1325@gmail.com',
      zip_safe=False)
